# -*- coding: utf8 -*
#
#  Gedit plugin to open a file manager at the location of the current file.
#
#  Copyright (C) 2006, Markus Jonsson <marjo691@student.liu.se>
#
#  Based on "Open Terminal Here" by Ramzi Ferchichi
#  Copyright (C) 2005, Ramzi Ferchichi <ramzi@gafouri.net>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#

import os 
import os.path

import gedit
import gtk
import gconf


FILE_MANAGER_HERE_UI = """
<ui>
  <menubar name="MenuBar">
    <menu name="ToolsMenu" action="Tools">
      <placeholder name="ToolsOps_2">
        <menuitem name="Show in File Manager" action="ShowInFileManager"/>
      </placeholder>
    </menu>
  </menubar>
  
  <popup name="NotebookPopup" action="NotebookPopupAction">
    <placeholder name="NotebookPupupOps_1">
      <menuitem name="Show in File Manager" action="ShowInFileManager"/>
    </placeholder>
  </popup>
</ui>
"""


#
# TODO:
#   - Handle non file:// uri's (check how nautilus-open-terminal does it)
#   - Thorough error checking
#   - I18N
#

class OpenFileManagerHerePlugin(gedit.Plugin):

	def __init__(self):
		
		gedit.Plugin.__init__(self)
		self.conf_client = gconf.client_get_default()


	def open_file_manager_cb(self, window):
		
		active_doc = window.get_active_document()
		document_dir = os.path.dirname(active_doc.get_uri()).replace("file://", "")

		#filemanager_exec = self.conf_client.get_string("/desktop/gnome/applications/terminal/exec")
		#if not filemanager_exec:
		file_manager_exec = "nautilus"

		os.chdir(document_dir)
		os.system(file_manager_exec + " " + document_dir + " &")


	def activate(self, window):	
		
		action = ("ShowInFileManager",
		          None,
		          "Show in _File Manager",
		          None,
		          "Show in File Manager",
		          lambda x, y: self.open_file_manager_cb(y))
		
		action_group = gtk.ActionGroup("ShowInFileManagerPluginActions")
		action_group.add_actions([action], window)

		ui_manager = window.get_ui_manager()
		ui_manager.insert_action_group(action_group, 0)
		ui_id = ui_manager.add_ui_from_string(FILE_MANAGER_HERE_UI)
		
		windowdata = dict()
		windowdata["action_group"] = action_group
		windowdata["ui_id"] = ui_id
		
		window.set_data("ShowInFileManagerPluginInfo", windowdata)


	def deactivate(self, window):

		windowdata = window.get_data("ShowInFileManagerPluginInfo")
		
		ui_manager = window.get_ui_manager()
		ui_manager.remove_ui(windowdata["ui_id"])
		ui_manager.remove_action_group(windowdata["action_group"])
		ui_manager.ensure_update()


	def is_valid_doc(self, doc):
		
		return bool(doc and
				    doc.get_uri() and
					doc.get_uri().startswith("file://"))


	def update_ui(self, window):

		windowdata = window.get_data("ShowInFileManagerPluginInfo")
		active_doc = window.get_active_document()
		windowdata["action_group"].set_sensitive(self.is_valid_doc(active_doc))

